@@ -18,16 +18,11 @@ from grai_source_postgres.package_definitions import config
 
 @multimethod
 def build_grai_metadata(current: Any, desired: Any) -> None:
-    raise NotImplementedError(
-        f"No adapter between {type(current)} and {type(desired)} for value {current}"
-    )
+    raise NotImplementedError(f"No adapter between {type(current)} and {type(desired)} for value {current}")
 
 
 @build_grai_metadata.register
-def build_grai_metadata_from_column(
-    current: Column, version: Literal["v1"] = "v1"
-) -> ColumnMetadata:
-
+def build_grai_metadata_from_column(current: Column, version: Literal["v1"] = "v1") -> ColumnMetadata:
     default_value = current.default_value
     if current.default_value is not None:
         default_value = DefaultValue(
@@ -51,9 +46,7 @@ def build_grai_metadata_from_column(
 
 
 @build_grai_metadata.register
-def build_grai_metadata_from_node(
-    current: Table, version: Literal["v1"] = "v1"
-) -> TableMetadata:
+def build_grai_metadata_from_node(current: Table, version: Literal["v1"] = "v1") -> TableMetadata:
     data = {
         "version": version,
         "node_type": NodeTypeLabels.table.value,
@@ -64,29 +57,25 @@ def build_grai_metadata_from_node(
 
 
 @build_grai_metadata.register
-def build_grai_metadata_from_edge(
-    current: Edge, version: Literal["v1"] = "v1"
-) -> GenericEdgeMetadataV1:
+def build_grai_metadata_from_edge(current: Edge, version: Literal["v1"] = "v1") -> GenericEdgeMetadataV1:
     data = {"version": version}
 
-    # if isinstance(current.source, Table) and isinstance(current.destination, Column):
-    if current.constraint_type.value == Constraint.belongs_to:
+    if isinstance(current.source, Table) and isinstance(current.destination, Column):
+        # if current.constraint_type.value == Constraint.belongs_to:
         data["edge_type"] = EdgeTypeLabels.table_to_column.value
         return TableToColumnMetadata(**data)
-    # elif isinstance(current.source, Column) and isinstance(current.destination, Column):
-    else:
+    elif isinstance(current.source, Column) and isinstance(current.destination, Column):
+        # else:
         data["edge_type"] = EdgeTypeLabels.column_to_column.value
         return ColumnToColumnMetadata(**data)
-    # else:
-    #     data["edge_type"] = EdgeTypeLabels.generic.value
-    #     return GenericEdgeMetadataV1(**data)
+    else:
+        data["edge_type"] = EdgeTypeLabels.generic.value
+        return GenericEdgeMetadataV1(**data)
 
 
 @multimethod
 def build_postgres_metadata(current: Any, desired: Any) -> None:
-    raise NotImplementedError(
-        f"No adapter between {type(current)} and {type(desired)} for value {current}"
-    )
+    raise NotImplementedError(f"No adapter between {type(current)} and {type(desired)} for value {current}")
 
 
 @build_postgres_metadata.register
