@@ -13,6 +13,9 @@ class ID(PostgresNode):
     namespace: str
     full_name: str
 
+    class Config:
+        extra = "forbid"
+
 
 class TableID(ID):
     table_schema: str
@@ -33,9 +36,7 @@ class ColumnID(ID):
     def make_full_name(cls, values):
         full_name = values.get("full_name", None)
         if values.get("full_name", None) is None:
-            values[
-                "full_name"
-            ] = f"{values['table_schema']}.{values['table_name']}.{values['name']}"
+            values["full_name"] = f"{values['table_schema']}.{values['table_name']}.{values['name']}"
         return values
 
 
@@ -68,8 +69,8 @@ class Constraint(str, Enum):
 
 
 class Edge(BaseModel):
-    source: Union[TableID, ColumnID]
-    destination: Union[TableID, ColumnID]
+    source: Union[ColumnID, TableID]
+    destination: Union[ColumnID, TableID]
     definition: Optional[str]
     constraint_type: Constraint
     metadata: Optional[Dict] = None
